/*
   GetSpFPaths() : Get path(s) of Windos's special folder(s) 
   
   Syntax : 
   
      GetSpFPaths( <xSFoldName> ) => <xPaths>
                       
   Argument : 
   
      <xSFoldName>  : Name(s) of Special Folder(s) to ask path 
   
   Return :
   
      <xPaths> : Full path(s) of asked special folder
      
   Description :

      <xSFoldName> : is name(s) of special folder(s). 
      
                     If it is a single character string assumed name of one folder,
                        and <xPaths> is a single string as of path that folder;
                     if it is an array, assumed a list of names of folders,
                        and <xPaths> is an array consisting strings as of path that folders.
                        
                     If <xSFoldName> not found into special folder <xPaths> too become a empty string.
                     
   Remarks : This work is based upon some info from Visual FoxPro Wiki site( http://fox.wikis.com )
             and builded on Windows Script Host (WSH). 
             
             Some notes about WSH from that site :
             
                 Windows Scripting Host is a Win32 application that allows
                 scripts to be run within the Windows environment. 
               
                 It is akin to the DOS Batch files, but much more powerful
               
                 It is a COM Server so you can get a reference to its object model
                 in any Windows COM compliant language plus Windows
                 (and DOS under Windows) can run the scripts itself.
               
                 Beware, however : 
               
                   - There are several releases of WSH that are not
                     completely compatible with one another. 
                   - Not all Windows versions came with WSH
                   - Even Windows versions that had WSH available may not have 
                     had WSH installed (or may have had it removed). 
                     
             A last note : some folders does not found into "special folders :
             
                 Contacts 
                 Downloads 
                 Links 
                 Music 
                 Pictures 
                 Saved Games 
                 Searches
*/

FUNCTION GetSpFPaths(;                  // Get Special Folders Paths List
                       xSFoldName )          // Name(s) of Special Folder(s) to ask path 
                       
	LOCAL oWshShell := CreateObject("WScript.Shell"),;   
         xRetVal
   
   IF ! EMPTY( xSFoldName )

      IF HB_IsChar( xSFoldName )
         xRetVal := oWshShell:SpecialFolders( xRetVal )
      ELSEIF HB_IsArray( xSFoldName )  
         xRetVal := {}
         AEVAL( xSFoldName, { | c1 | AADD( xRetVal, oWshShell:SpecialFolders( STRTRAN( c1, " ", "" ) ) ) } )
      ENDIF   
      
   ENDIF ! EMPTY( xSFoldName )
   
   oWshShell := Nil
  
RETURN xRetVal // GetSpFPaths()

*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

